components/button/enums/pi_button_shape_enum library

V Button Shape Enum This file defines the PiButtonShape enum which specifies the shape of the PiButton widget.

Enums

PiButtonShape
Enum representing different shapes for a button.

Extensions

PiButtonShapeRounded on PiButtonShape
Extension on PiButtonShape to provide additional properties.