PiButtonShape enum

Enum representing different shapes for a button.

Inheritance
Available extensions

Values

ROUNDED → const PiButtonShape

A button with rounded corners.

const PiButtonShape(id: "ROUNDED", name: "Rounded")
ROUNDED_FULL → const PiButtonShape

A button with rounded_full corners.

const PiButtonShape(id: "ROUNDED_FULL", name: "Rounded_full")
SQUARE → const PiButtonShape

A square-shaped button.

const PiButtonShape(id: "SQUARE", name: "Square")
CIRCLE → const PiButtonShape

A circular button.

const PiButtonShape(id: "CIRCLE", name: "Circle")

Properties

borderRadius BorderRadius

Available on PiButtonShape, provided by the PiButtonShapeRounded extension

Returns the border radius based on the button shape.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the shape.
final
index int
A numeric identifier for the enumerated value.
no setterinherited
isCircle bool
Checks if the shape is circular.
no setter
isRounded bool
Checks if the shape is rounded.
no setter
isRoundedFull bool
Checks if the shape is rounded_full.
no setter
isSquare bool
Checks if the shape is square.
no setter
name String
Display name for the shape.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PiButtonShape>
A constant List of the values in this enum, in order of their declaration.