PiButtonSize enum

Enum representing different button sizes.

Inheritance
Available extensions

Values

SMALL → const PiButtonSize

A small-sized button.

const PiButtonSize(id: "SMALL", name: "Small")
MEDIUM → const PiButtonSize

A medium-sized button.

const PiButtonSize(id: "MEDIUM", name: "Medium")
LARGE → const PiButtonSize

A large-sized button.

const PiButtonSize(id: "LARGE", name: "Large")

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the size.
final
index int
A numeric identifier for the enumerated value.
no setterinherited
isLarge bool
Checks if the size is large.
no setter
isMedium bool
Checks if the size is medium.
no setter
isSmall bool
Checks if the size is small.
no setter
name String
Display name for the size.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PiButtonSize>
A constant List of the values in this enum, in order of their declaration.