PiButtonFontSizeThemeData class

Inheritance

Constructors

PiButtonFontSizeThemeData({dynamic small, dynamic medium, dynamic large})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
large double
no setteroverride
medium double
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small double
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited