PiButtonThemeData class

Properties

backgroundColor PiButtonColorThemeData?
no setter
fontSize PiButtonFontSizeThemeData
no setter
forgroundColor PiButtonColorThemeData?
no setter
hashCode int
The hash code for this object.
no setterinherited
iconSize PiButtonIconSizeThemeData
no setter
padding PiButtonPaddingThemeData
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape PiButtonShapeThemeData
no setter
size PiButtonSizeThemeData
no setter
splashColor PiButtonColorThemeData?
no setter
textStyle TextStyle
no setter
type PiButtonTypeThemeData
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited