PiColorData class

Constructors

PiColorData({Color? primary, Color? secondary, Color? info, Color? waning, Color? success, Color? danger, Color? disable})
const

Properties

danger Color
no setter
disable Color
no setter
hashCode int
The hash code for this object.
no setterinherited
info Color
no setter
primary Color
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
no setter
success Color
no setter
warning Color
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited