PiThemeData class

A class that holds the theme data for VTheme

Constructors

PiThemeData({String? debugLabel, PiColorData? colorTheme, PiButtonThemeData? piButtonThemeData})
Creates a new instance of PiThemeData
const

Properties

colorTheme PiColorData
no setter
debugLabel String
no setter
hashCode int
The hash code for this object.
no setterinherited
piButtonThemeData PiButtonThemeData
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? debugLabel, PiColorData? colorTheme, PiButtonThemeData? piButtonThemeData}) PiThemeData
Creates a copy of this VThemeData with the given fields replaced with the new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited