dioError403 property

PiLocalizationModel dioError403
getter/setter pair

Implementation

static var dioError403 = PiLocalizationModel(
  key: 'message.dio.error.403',
  idValue:
      "Maaf, pengguna yang terotentikasi tidak diizinkan untuk mengakses titik API yang ditentukan. Silakan coba lagi.",
  enValue:
      "Sorry, authenticated users are not allowed to access the specified API endpoint. Please try again.",
);