dioError415 property

PiLocalizationModel dioError415
getter/setter pair

Implementation

static var dioError415 = PiLocalizationModel(
  key: 'message.dio.error.415',
  idValue:
      "Maaf, jenis media yang diminta tidak didukung. Jenis konten atau nomor versi yang diminta tidak valid. Silakan coba lagi.",
  enValue:
      "Sorry, the requested media type is not supported. The requested content type or version number is not valid. Please try again.",
);