PiButtonShapeThemeData class
Properties
-
circle
→ BorderRadius
-
Returns the circle border radius, or a default value if not set
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
rounded
→ BorderRadius
-
Returns the rounded border radius, or a default value if not set
no setter
-
roundedFull
→ BorderRadius
-
Returns the rounded full border radius, or a default value if not set
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
square
→ BorderRadius
-
Returns the square border radius, or a default value if not set
no setter
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited